@@ -47,6 +47,7 @@
 #include <QAction>
 
 #include <klocalizedstring.h>
+#include <kmessagebox.h>
 
 AltTransView::AltTransView(QWidget* parent, Catalog* catalog,const QVector<QAction*>& actions)
     : QDockWidget ( i18nc("@title:window","Alternate Translations"), parent)
@@ -174,7 +175,16 @@ void AltTransView::process()
         m_hasInfo=true;
         setWindowTitle(m_hasInfoTitle);
     }
+    if(!isVisible() && !Settings::altTransViewEverShownWithData())
+    {
+        if (KMessageBox::questionYesNo(this,i18n("There is useful data available in Alternate Translations view.\n\n"
+            "For Gettext PO files it displays difference between current source text "
+            "and the source text corresponding to the fuzzy translation found by msgmerge when updating PO based on POT template.\n\n"
+            "Do you want to show the view with the data?"), m_normTitle)==KMessageBox::Yes)
+          show();
 
+        Settings::setAltTransViewEverShownWithData(true);
+    }
 
     CatalogString source=m_catalog->sourceWithTags(m_entry.toDocPosition());
 
